"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Handles events.
 */
var EventTarget = /** @class */ (function () {
    function EventTarget() {
        this._listeners = {};
    }
    /**
     * Adds an event listener.
     *
     * @param {string} type Event type.
     * @param {function} listener Listener.
     */
    EventTarget.prototype.addEventListener = function (type, listener) {
        this._listeners[type] = this._listeners[type] || [];
        this._listeners[type].push(listener);
    };
    /**
     * Adds an event listener.
     *
     * @param {string} type Event type.
     * @param {function} listener Listener.
     */
    EventTarget.prototype.removeEventListener = function (type, listener) {
        if (this._listeners[type]) {
            var index = this._listeners[type].indexOf(listener);
            if (index !== -1) {
                this._listeners[type].splice(index);
            }
        }
    };
    /**
     * Dispatches an event.
     *
     * @param {Event} event Event.
     * @return {boolean} The return value is false if event is cancelable and at least one of the event handlers which handled this event called Event.preventDefault()
     */
    EventTarget.prototype.dispatchEvent = function (event) {
        var returnValue = true;
        if (this._listeners[event.type]) {
            for (var _i = 0, _a = this._listeners[event.type]; _i < _a.length; _i++) {
                var listener = _a[_i];
                listener(event);
                if (event.cancelable && event.defaultPrevented) {
                    returnValue = false;
                }
                if (event._immediatePropagationStopped) {
                    return returnValue;
                }
            }
        }
        return returnValue;
    };
    return EventTarget;
}());
exports.default = EventTarget;
//# sourceMappingURL=EventTarget.js.map