import Element from '../nodes/basic-types/element/Element';
import Node from '../nodes/basic-types/node/Node';
/**
 * Utility for query selection in a Node.
 *
 * @class QuerySelector
 */
export default class QuerySelector {
    /**
     * Finds elements based on a query selector.
     *
     * @param {string} node Node to search in.
     * @param {string} selector Selector.
     * @return {Element[]} HTML elements.
     */
    static querySelectorAll(node: Node, selector: string): Element[];
    /**
     * Finds an element based on a query selector.
     *
     * @param {string} node Node to search in.
     * @param {string} selector Selector.
     * @return {Element} HTML element.
     */
    static querySelector(node: Node, selector: string): Element;
    /**
     * Finds elements based on a query selector for a part of a list of selectors separated with comma.
     *
     * @param {string} node Node to search in.
     * @param {string} selector Selector.
     * @return {Element[]} HTML elements.
     */
    private static querySelectorAllForPart;
    /**
     * Finds an element based on a query selector for a part of a list of selectors separated with comma.
     *
     * @param {string} node Node to search in.
     * @param {string} selector Selector.
     * @return {Element} HTML element.
     */
    private static querySelectorForPart;
}
